@@ -16,7 +16,8 @@ Werthmüller for ``empymod``, ``emg3d``, and the ``SimPEG`` framework
 """
 
 from scooby.report import Report, get_version
-from scooby.knowledge import get_standard_lib_modules, in_ipython, in_ipykernel
+from scooby.knowledge import (get_standard_lib_modules, in_ipykernel,  # noqa
+                              in_ipython, meets_version, version_tuple)
 from scooby.tracker import TrackedReport, track_imports, untrack_imports
 
 __all__ = ['Report', 'TrackedReport', 'get_standard_lib_modules', 'in_ipython',
@@ -26,4 +27,4 @@ __all__ = ['Report', 'TrackedReport', 'get_standard_lib_modules', 'in_ipython',
 __author__ = 'Dieter Werthmüller & Bane Sullivan'
 __license__ = 'MIT'
 __copyright__ = '2019, Dieter Werthmüller & Bane Sullivan'
-__version__ = '0.5.0'
+__version__ = '0.5.6'
