@@ -174,17 +174,18 @@ class Report(PlatformInfo, PythonInfo):
 
         if extra_meta is not None:
             if not isinstance(extra_meta, (list, tuple)):
-                raise TypeError("`extra_meta` must be a list/tuple of key-value pairs.")
+                raise TypeError("`extra_meta` must be a list/tuple of "
+                                "key-value pairs.")
             if len(extra_meta) == 2 and isinstance(extra_meta[0], str):
                 extra_meta = [extra_meta]
             for meta in extra_meta:
                 if not isinstance(meta, (list, tuple)) or len(meta) != 2:
-                    raise TypeError("Each chunk of meta info must have two values.")
+                    raise TypeError(
+                            "Each chunk of meta info must have two values.")
         else:
             extra_meta = []
         self._extra_meta = extra_meta
 
-
     def __repr__(self):
         """Plain-text version information."""
 
@@ -201,15 +202,13 @@ class Report(PlatformInfo, PythonInfo):
         text += date_text+'\n'
 
         # ########## Platform/OS details ############
-        text += '{:>18}'.format(self.system)+' : OS\n'
-        text += '{:>18}'.format(self.cpu_count)+' : CPU(s)\n'
-        text += '{:>18}'.format(self.machine)+' : Machine\n'
-        text += '{:>18}'.format(self.architecture)+' : Architecture\n'
-        if TOTAL_RAM:
-            text += '{:>18}'.format(self.total_ram)+' : RAM\n'
-        text += '{:>18}'.format(self.python_environment)+' : Environment\n'
+        repr_dict = self.to_dict()
+        for key in ['OS', 'CPU(s)', 'Machine', 'Architecture', 'RAM',
+                    'Environment']:
+            if key in repr_dict:
+                text += '{:>18} : {}\n'.format(key, repr_dict[key])
         for meta in self._extra_meta:
-            text += '{:>18}'.format(meta[1])+' : {}\n'.format(meta[0])
+            text += '{:>18}'.format(meta[0])+' : {}\n'.format(meta[1])
 
         # ########## Python details ############
         text += '\n'
@@ -219,7 +218,7 @@ class Report(PlatformInfo, PythonInfo):
         text += '\n'
 
         # Loop over packages
-        for name, version in self._packages.items():
+        for version, name in self._packages.items():
             text += '{:>18} : {}\n'.format(version, name)
 
         # ########## MKL details ############
@@ -261,10 +260,10 @@ class Report(PlatformInfo, PythonInfo):
                 html += "  <tr>\n"
 
             html += "    <td style='text-align: right; background-color: #ccc;"
-            html += " " + border + ">%s</td>\n" % version
+            html += " " + border + ">%s</td>\n" % name
 
             html += "    <td style='text-align: left; "
-            html += border + ">%s</td>\n" % name
+            html += border + ">%s</td>\n" % version
 
             return html, i+1
 
@@ -272,19 +271,16 @@ class Report(PlatformInfo, PythonInfo):
         html = "<table style='border: 3px solid #ddd;'>\n"
 
         # Date and time info as title
-        html = colspan(html, self.date,
-                       self.ncol, 0)
+        html = colspan(html, self.date, self.ncol, 0)
 
         # ########## Platform/OS details ############
         html += "  <tr>\n"
-        html, i = cols(html, self.system, 'OS', self.ncol, 0)
-        html, i = cols(html, self.cpu_count, 'CPU(s)', self.ncol, i)
-        html, i = cols(html, self.machine, 'Machine', self.ncol, i)
-        html, i = cols(html, self.architecture, 'Architecture', self.ncol, i)
-        if TOTAL_RAM:
-            html, i = cols(html, self.total_ram, 'RAM', self.ncol, i)
-        html, i = cols(
-                html, self.python_environment, 'Environment', self.ncol, i)
+        repr_dict = self.to_dict()
+        i = 0
+        for key in ['OS', 'CPU(s)', 'Machine', 'Architecture', 'RAM',
+                    'Environment']:
+            if key in repr_dict:
+                html, i = cols(html, repr_dict[key], key, self.ncol, i)
         for meta in self._extra_meta:
             html, i = cols(html, meta[1], meta[0], self.ncol, i)
         # Finish row
@@ -315,6 +311,37 @@ class Report(PlatformInfo, PythonInfo):
 
         return html
 
+    def to_dict(self):
+        """Return report as dict for storage."""
+
+        out = {}
+
+        # Date and time info
+        out['Date'] = self.date
+
+        # Platform/OS details
+        out['OS'] = self.system
+        out['CPU(s)'] = str(self.cpu_count)
+        out['Machine'] = self.machine
+        out['Architecture'] = self.architecture
+        if TOTAL_RAM:
+            out['RAM'] = self.total_ram
+        out['Environment'] = self.python_environment
+        for meta in self._extra_meta:
+            out[meta[1]] = meta[0]
+
+        # Python details
+        out['Python'] = self.sys_version
+
+        # Loop over packages
+        for name, version in self._packages.items():
+            out[name] = version
+
+        # MKL details
+        if MKL_INFO:
+            out['MKL'] = MKL_INFO
+
+        return out
 
 
 # This functionaliy might also be of interest on its own.
